@@ -6,8 +6,9 @@ import signal
 import typing
 import getpass
 import logging
+import base64
 import threading
-from typing import Any, Dict, List, Type, Callable, Optional, DefaultDict, Tuple
+from typing import Any, Dict, List, Type, Callable, Optional, DefaultDict, Tuple, Union
 from types import FrameType
 from collections import defaultdict
 
@@ -27,7 +28,7 @@ class Telegram:
         self,
         api_id: int,
         api_hash: str,
-        database_encryption_key: str,
+        database_encryption_key: Union[str, bytes],
         phone: Optional[str] = None,
         bot_token: Optional[str] = None,
         library_path: Optional[str] = None,
@@ -42,6 +43,10 @@ class Telegram:
         login: bool = False,
         default_workers_queue_size: int = 1000,
         tdlib_verbosity: int = 2,
+        proxy_server: str = '',
+        proxy_port: int = 0,
+        proxy_type: Optional[Dict[str, str]] = None,
+        use_secret_chats: bool = True,
     ) -> None:
         """
         Args:
@@ -53,6 +58,7 @@ class Telegram:
             files_directory - directory for the tdlib's files (database, images, etc.)
             use_test_dc - use test datacenter
             use_message_database
+            use_secret_chats
             device_model
             application_version
             system_version
@@ -70,6 +76,10 @@ class Telegram:
         self.application_version = application_version
         self.use_message_database = use_message_database
         self._queue_put_timeout = 10
+        self.proxy_server = proxy_server
+        self.proxy_port = proxy_port
+        self.proxy_type = proxy_type
+        self.use_secret_chats = use_secret_chats
 
         if not self.bot_token and not self.phone:
             raise ValueError('You must provide bot_token or phone')
@@ -166,7 +176,7 @@ class Telegram:
 
         return self.call_method('getMe')
 
-    def get_user(self, user_id) -> AsyncResult:
+    def get_user(self, user_id: int) -> AsyncResult:
         """
         Requests information about a user with id = user_id.
 
@@ -228,11 +238,7 @@ class Telegram:
 
         return self._send_data(data)
 
-    def get_message(
-        self,
-        chat_id: int,
-        message_id: int,
-    ) -> AsyncResult:
+    def get_message(self, chat_id: int, message_id: int,) -> AsyncResult:
         """
         Return a message via its message_id
 
@@ -259,6 +265,48 @@ class Telegram:
         }
         return self._send_data(data)
 
+    def delete_messages(
+        self, chat_id: int, message_ids: List[int], revoke: bool = True
+    ) -> AsyncResult:
+        """
+        Delete a list of messages in a chat
+
+        Args:
+            chat_id
+            message_ids
+            revoke
+        """
+        return self._send_data(
+            {
+                '@type': 'deleteMessages',
+                'chat_id': chat_id,
+                'message_ids': message_ids,
+                'revoke': revoke,
+            }
+        )
+
+    def get_supergroup_full_info(self, supergroup_id: int) -> AsyncResult:
+        """
+        Get the full info of a supergroup
+
+        Args:
+            supergroup_id
+        """
+        return self._send_data(
+            {'@type': 'getSupergroupFullInfo', 'supergroup_id': supergroup_id}
+        )
+
+    def create_basic_group_chat(self, basic_group_id: int) -> AsyncResult:
+        """
+        Create a chat from a basic group
+
+        Args:
+            basic_group_id
+        """
+        return self._send_data(
+            {'@type': 'createBasicGroupChat', 'basic_group_id': basic_group_id}
+        )
+
     def get_web_page_instant_view(
         self, url: str, force_full: bool = False
     ) -> AsyncResult:
@@ -275,7 +323,10 @@ class Telegram:
         return self._send_data(data)
 
     def call_method(
-            self, method_name: str, params: Optional[Dict[str, Any]] = None, block: bool = False,
+        self,
+        method_name: str,
+        params: Optional[Dict[str, Any]] = None,
+        block: bool = False,
     ) -> AsyncResult:
         """
         Use this method to call any other method of the tdlib
@@ -363,7 +414,10 @@ class Telegram:
             self._update_handlers[handler_type].append(func)
 
     def _send_data(
-            self, data: Dict[Any, Any], result_id: Optional[str] = None, block: bool = False,
+        self,
+        data: Dict[Any, Any],
+        result_id: Optional[str] = None,
+        block: bool = False,
     ) -> AsyncResult:
         """
         Sends data to tdlib.
@@ -416,6 +470,9 @@ class Telegram:
         Must be called before any other call.
         It sends initial params to the tdlib, sets database encryption key, etc.
         """
+        if self.proxy_server:
+            self._send_add_proxy()
+
         authorization_state = None
         actions = {
             None: self.get_authorization_state,
@@ -466,6 +523,7 @@ class Telegram:
                 'database_directory': os.path.join(self.files_directory, 'database'),
                 'use_message_database': self.use_message_database,
                 'files_directory': os.path.join(self.files_directory, 'files'),
+                'use_secret_chats': self.use_secret_chats,
             },
         }
 
@@ -473,9 +531,14 @@ class Telegram:
 
     def _send_encryption_key(self) -> AsyncResult:
         logger.info('Sending encryption key')
+
+        key = self._database_encryption_key
+        if isinstance(key, str):
+            key = key.encode()
+
         data = {
             '@type': 'checkDatabaseEncryptionKey',
-            'encryption_key': self._database_encryption_key,
+            'encryption_key': base64.b64encode(key).decode(),
         }
 
         return self._send_data(data, result_id='updateAuthorizationState')
@@ -500,6 +563,17 @@ class Telegram:
 
         return self._send_data(data, result_id='updateAuthorizationState')
 
+    def _send_add_proxy(self) -> AsyncResult:
+        logger.info('Sending addProxy')
+        data = {
+            '@type': 'addProxy',
+            'server': self.proxy_server,
+            'port': self.proxy_port,
+            'enable': True,
+            'type': self.proxy_type,
+        }
+        return self._send_data(data, result_id='setProxy')
+
     def _send_bot_token(self) -> AsyncResult:
         logger.info('Sending bot token')
         data = {'@type': 'checkAuthenticationBotToken', 'token': self.bot_token}
